@@ -10,6 +10,7 @@ from cnvrgv2.cli.utils import messages
 from cnvrgv2.cli.modules.users import users
 from cnvrgv2.cli.logger.logger import CnvrgLogger
 from cnvrgv2.cli.modules.project.project import project_group
+from cnvrgv2.cli.modules.libraries.library import library_group
 from cnvrgv2.cli.modules.dataset.dataset import dataset_group
 from cnvrgv2.cli.modules.project.experiment import experiment_group
 
@@ -49,6 +50,7 @@ entry_point.add_command(users.login)
 entry_point.add_command(users.logout)
 entry_point.add_command(CnvrgLogger.set_logs_keep_duration)
 entry_point.add_command(project_group)
+entry_point.add_command(library_group)
 entry_point.add_command(experiment_group)
 entry_point.add_command(dataset_group)
 entry_point.add_command(ssh_group)
