@@ -26,8 +26,10 @@ DATA_UPLOAD_HELP_GIT_DIFF = "From the list of files, upload those who returned f
 
 # DATASET
 DATASET_PROMPT_CLONE = "Please enter dataset name to clone"
+DATASET_PROMPT_COMMIT = "Please enter sha1 to clone, default is latest"
 DATASET_HELP_CLONE = "Name of the dataset to clone"
 DATASET_HELP_CLONE_OVERRIDE = "Whether or not re-clone in case the dataset already cloned"
+DATASET_HELP_CLONE_COMMIT = "The commit sha1 to clone"
 DATASET_CLONE_SKIP = "Dataset {0} is already cloned, therefore skip clone." \
                      " If you want to override, run again using -o flag."
 DATASET_PROMPT_NAME = "Please enter dataset name"
@@ -43,8 +45,10 @@ DATASET_REMOVE_SUCCESS = "Files removed successfully"
 
 # PROJECT
 PROJECT_PROMPT_CLONE = "Please enter project name to clone"
+PROJECT_PROMPT_COMMIT = "Please enter sha1 to clone, default is latest"
 PROJECT_HELP_CLONE = "Name of the project to clone"
 PROJECT_HELP_CLONE_OVERRIDE = "Whether or not re-clone in case the project already cloned"
+PROJECT_HELP_CLONE_COMMIT = "The commit sha1 to clone"
 PROJECT_CLONE_SKIP = "Project {0} is already cloned, therefore skip clone." \
                      " If you want to override, run again using -o flag."
 PROJECT_CLONE_SUCCESS = "Successfully cloned project: {0}"
@@ -66,6 +70,12 @@ PROJECT_CREATING_PROJECT = "Creating new project {0}"
 PROJECT_CREATE_SUCCESS = "Successfully created project {0}"
 PROJECT_DOWNLOAD_HELP_COMMIT = "Sha1 of the commit to download"
 
+# LIBRARIES
+LIBRARY_PROMPT_CLONE = "Please enter library name to clone"
+LIBRARY_VERSION_PROMPT_CLONE = "Please enter library version name to clone (default = \"latest\")"
+LIBRARY_CLONE_SKIP = "Library {0} is already cloned, skipping action"
+LIBRARY_CLONE_SUCCESS = "Successfully cloned project: {0}"
+
 
 # EXPERIMENT
 EXPERIMENT_PROMPT_TITLE = "Please enter a title for the experiment"
@@ -86,6 +96,7 @@ EXPERIMENT_CREATE_SUCCESS = "Experiment {0} created successfully. \r\nExperiment
 # LOGS
 LOG_START_COMMAND = "Starting command {0}. Options: {1}"
 LOG_CLONING_PROJECT = "Cloning project: {0}"
+LOG_CLONING_LIBRARY = "Cloning library: {0}=={1}"
 LOG_CLONING_DATASET = "Cloning dataset: {0}"
 
 # SSH
