@@ -9,7 +9,7 @@ from itertools import chain
 
 from cnvrgv2.modules.folder import Folder
 from cnvrgv2.proxy import HTTP
-from cnvrgv2.errors import CnvrgFileError, CnvrgArgumentsError
+from cnvrgv2.errors import CnvrgFileError, CnvrgArgumentsError, CnvrgError
 from cnvrgv2.cli.utils.progress_bar_utils import init_progress_bar_for_cli
 
 from cnvrgv2.config.routes import COMMIT_REMOVE_FILES
@@ -26,7 +26,12 @@ from cnvrgv2.data import ArtifactsDownloader
 from cnvrgv2.utils.converters import convert_bytes
 from cnvrgv2.utils.url_utils import urljoin
 from cnvrgv2.utils.filter_utils import list_to_multiple_conditions, Operators
-from cnvrgv2.utils.storage_utils import get_files_and_dirs_recursive, create_dir_if_not_exists, filter_by_mimetypes
+from cnvrgv2.utils.storage_utils import (
+    get_files_and_dirs_recursive,
+    create_dir_if_not_exists,
+    filter_by_mimetypes,
+    create_cnvrgignore,
+    cnvrgignore_exists)
 from cnvrgv2.utils.api_list_generator import api_list_generator
 
 from cnvrgv2.modules.file import File
@@ -212,7 +217,12 @@ class DataOwner(DynamicAttributes):
             is_file = os.path.isfile(path)
 
             if is_dir:
-                fullpaths += get_files_and_dirs_recursive(root_dir=path, regex=pattern, not_tmp=True, filters=filters)
+                fullpaths += get_files_and_dirs_recursive(
+                    root_dir=path,
+                    regex=pattern,
+                    not_tmp=True,
+                    project_root=self._config.root,
+                    filters=filters)
             elif is_file:
                 if filter_by_mimetypes(filters, path):
                     fullpaths.append(path)
@@ -238,10 +248,10 @@ class DataOwner(DynamicAttributes):
             # TODO: different handling?
             return
 
-        if job_slug is not None:
-            last_commit = self.last_commit
-            if last_commit is None and self.start_commit is not None:
-                last_commit = self.start_commit["sha1"]
+        last_commit = self.local_commit
+
+        if job_slug is not None and last_commit is None and self.start_commit is not None:
+            last_commit = self.start_commit["sha1"]
 
         new_unique_fullpaths = []
         tmp_folder = "{}/{}".format(self.working_dir, DataOwner.TMP_FOLDER_NAME)
@@ -281,7 +291,6 @@ class DataOwner(DynamicAttributes):
             deleter = RemoteFileDeleter(self, commit=commit_sha1)
             while deleter.in_progress:
                 time.sleep(0.1)
-
         self._end_commit(commit_sha1=commit_sha1, tag_images=tag_images)
 
         return commit_sha1
@@ -339,11 +348,12 @@ class DataOwner(DynamicAttributes):
             payload=data
         ).meta
 
-    def clone(self, progress_bar_enabled=False, override=False):
+    def clone(self, progress_bar_enabled=False, override=False, commit=None):
         """
         Clones the remote project / dataset
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
         @param override: Boolean stating whether or not we should re-clone even if the project / dataset already cloned
+        @param commit: [String] sha1 of the commit to clone
         @return: None
         """
 
@@ -355,6 +365,9 @@ class DataOwner(DynamicAttributes):
             # If already cloned and override set to false - won't clone again
             return
 
+        if commit:
+            self.last_commit = commit
+
         old_working_dir = self.working_dir
         self.working_dir = "{}/{}".format(old_working_dir, self.slug)
 
@@ -363,12 +376,21 @@ class DataOwner(DynamicAttributes):
         while downloader.in_progress:
             time.sleep(1)
 
+        if downloader.errors:
+            if os.path.exists(self.slug) and not override:
+                os.rmdir(self.slug)
+            raise CnvrgError(downloader.errors.args)
+
+
         self.local_commit = self.last_commit
         self.save_config(local_config_path=self.working_dir + '/' + CONFIG_FOLDER_NAME)
 
         self.reload()
         self.working_dir = old_working_dir
 
+        if not cnvrgignore_exists(self.slug):
+            create_cnvrgignore(self.slug)
+
     def upload(self, sync=False, job_slug=None, progress_bar_enabled=False, git_diff=False):
         """
         Uploads files to remote project / dataset
@@ -384,8 +406,11 @@ class DataOwner(DynamicAttributes):
         if not self._validate_config_ownership():
             raise CnvrgFileError(error_messages.CONFIG_YAML_NOT_FOUND)
 
+        old_working_dir = os.getcwd()
+        os.chdir(self._config.root)
+
         new_commit_sha1 = self.put_files(
-            ["."],
+            [self._config.root],
             upload=True,
             job_slug=job_slug,
             progress_bar_enabled=progress_bar_enabled,
@@ -397,6 +422,7 @@ class DataOwner(DynamicAttributes):
 
         self.local_commit = new_commit_sha1
         self.save_config()
+        os.chdir(old_working_dir)
 
     def download(self, sync=False, progress_bar_enabled=False, commit_sha1=None):
         """
@@ -412,6 +438,9 @@ class DataOwner(DynamicAttributes):
         if not self._validate_config_ownership():
             raise CnvrgFileError(error_messages.CONFIG_YAML_NOT_FOUND)
 
+        context_working_dir = os.getcwd()
+        os.chdir(self._config.root)
+
         """
         download files from last commit on the server and put them in .tmp folder
         will be fetched at the end out of .tmp
@@ -451,6 +480,8 @@ class DataOwner(DynamicAttributes):
             self.local_commit = commit_sha1 or self.last_commit
             self.save_config()
 
+        os.chdir(context_working_dir)
+
     def sync(self, job_slug=None, git_diff=False):
         """
         Sync local project / dataset to remote
