@@ -1,15 +1,15 @@
 from cnvrgv2.config import routes, error_messages
+from cnvrgv2.config.error_messages import FAULTY_KEY
 from cnvrgv2.proxy import Proxy, HTTP
 from cnvrgv2.context import Context, SCOPE
 from cnvrgv2.modules.base.data_owner import DataOwner
 from cnvrgv2.utils.json_api_format import JAF
 from cnvrgv2.utils.url_utils import urljoin
-from cnvrgv2.utils.validators import attributes_validator
+from cnvrgv2.utils.validators import attributes_validator, validate_secret_key
 from cnvrgv2.errors import CnvrgArgumentsError
 
 
 class ProjectSettings(DataOwner):
-
     available_attributes = {
         "title": str,
         "default_image": str,
@@ -77,7 +77,7 @@ class ProjectSettings(DataOwner):
         )
 
         if "secrets" in kwargs:
-            raise CnvrgArgumentsError(error_messages.NOT_SUPPORTED.format("secrets"))
+            raise CnvrgArgumentsError(error_messages.SECRETS_NOT_SUPPORTED.format("secrets"))
 
         response = self._proxy.call_api(
             route=self._route,
@@ -88,3 +88,39 @@ class ProjectSettings(DataOwner):
         response_attributes = response.attributes
         response_attributes.pop('slug', None)
         self._attributes = response_attributes
+
+    def update_secret(self, secret_key, secret_value, force=False):
+        """
+        update or add a single secret
+        @param secret_key: [String] Secret Key
+        @param secret_value: [String] Secret Value
+        @param force: Override existing secrets
+        @return: None
+        """
+        if not validate_secret_key(secret_key):
+            raise CnvrgArgumentsError(FAULTY_KEY.format(secret_key))
+
+        update_secret_url = urljoin(self._route, routes.PROJECT_UPDATE_SECRET)
+
+        self._proxy.call_api(
+            route=update_secret_url,
+            http_method=HTTP.POST,
+            payload=JAF.serialize(type="settings", attributes={"secret_key": secret_key, "secret_value": secret_value, "force": force})
+        )
+
+    def delete_secret(self, secrets):
+        """
+        delete single or list of secrets
+        @param secrets: [List] of Keys
+        @return: None
+        """
+        if isinstance(secrets, str):
+            secrets = [secrets]
+
+        delete_secret_url = urljoin(self._route, routes.PROJECT_DELETE_SECRET)
+
+        self._proxy.call_api(
+            route=delete_secret_url,
+            http_method=HTTP.POST,
+            payload=JAF.serialize(type="settings", attributes={"secrets": secrets})
+        )
