@@ -26,12 +26,17 @@ def validate_user_role(role):
     return role in ROLES.ALL_ROLES
 
 
+def validate_secret_key(key):
+    regex = r'^[a-zA-Z_][a-zA-Z0-9_]*$'
+    return re.match(regex, key) is not None
+
+
 def validate_username(username):
     regex = r'^[A-Za-z0-9]+$'
     return re.search(regex, username) is not None
 
 def validate_directory_name(paths):
-    regex = r'^[a-zA-Z0-9_\/-]+$'
+    regex = r"^[a-zA-Z0-9_.()'!\/-]+$"
     for path in paths:
         is_dir = os.path.isdir(path)
         if is_dir and not re.match(regex, path):
